# molten

[![Build Status](https://travis-ci.org/Bogdanp/molten.svg?branch=master)](https://travis-ci.org/Bogdanp/molten)
[![Maintainability](https://api.codeclimate.com/v1/badges/f7ab5fdd188fda33c3e1/maintainability)](https://codeclimate.com/github/Bogdanp/molten/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/f7ab5fdd188fda33c3e1/test_coverage)](https://codeclimate.com/github/Bogdanp/molten/test_coverage)
[![PyPI version](https://badge.fury.io/py/molten.svg)](https://badge.fury.io/py/molten)
[![Documentation](https://img.shields.io/badge/doc-latest-brightgreen.svg)](https://moltenframework.com)
[![Reddit](https://img.shields.io/badge/discuss-online-orange.svg)](https://www.reddit.com/r/moltenframework/)

*A minimal, extensible, fast and productive API framework for Python 3.*

<hr/>

**Changelog**: https://moltenframework.com/changelog.html <br/>
**Community**: https://www.reddit.com/r/moltenframework/ <br/>
**Documentation**: https://moltenframework.com

<hr/>


## Installation

    pip install molten


## Quickstart

Check out the [examples] folder to get a taste of the framework or
read the [user guide]!


## License

molten is licensed under the LGPL.  Please see [COPYING] and
[COPYING.LESSER] for licensing details.

[COPYING.LESSER]: https://github.com/Bogdanp/molten/blob/master/COPYING.LESSER
[COPYING]: https://github.com/Bogdanp/molten/blob/master/COPYING
[examples]: https://github.com/Bogdanp/molten/blob/master/examples
[user guide]: https://moltenframework.com/guide.html
